from setuptools import setup

setup(name='dmj_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['dmj_distributions'],
      author='David Lin',
      author_email='dbspace@yahoo.com',
      zip_safe=False)
